@@ -34,10 +34,10 @@ Usage:
         port: log.io api port (default 28777)
 """
 
-VERSION = '1.1.1'
+VERSION = '1.1.2'
 AUTHOR = "Raymond McGinlay"
 EMAIL = "raymond@thisislevelup.com"
-URL = "www.thisislevelup.com"
+URL = "https://github.com/Level-Up/python_log_io"
 
 
 class LogIOHandler(logging.Handler):
